#!/bin/sh

OSTYPE=`uname -s`
MACHINE=`uname -m`

echo "Host info: $OSTYPE $MACHINE"
echo ""

# If we're on OS X, use glibtoolize instead of toolize
if [ "$OSTYPE" == "Darwin" ]; then
    LIBTOOLIZE=glibtoolize
else
    LIBTOOLIZE=libtoolize
fi


# Check Automake version
if [ -x `which automake` ]; then
    AM_VERSION=`automake --version | head -1 | awk '{print $4}' | sed -e 's/\.\([0-9]*\).*/\1/'`
    if test $AM_VERSION -lt 15; then
        echo ""
        echo "You need to upgrade to automake version 1.5 or greater."
        echo "Most distributions have packages available to install or you can"
        echo "find the source for the most recent version at"
        echo "ftp://ftp.gnu.org/gnu/automake"
        exit 1
    fi
else
    echo automake not found. renderBitch SVN requires automake to bootstrap itself.
    exit 1
fi


# Check Autoconf version
if [ -x `which autoconf` ]; then
    AC_VER=`autoconf --version | head -n 1 | sed 's/^[^0-9]*//'`
    AC_VER_MAJOR=`echo $AC_VER | cut -f1 -d'.'`
    AC_VER_MINOR=`echo $AC_VER | cut -f2 -d'.' | sed 's/[^0-9]*$//'`

    if [ "$AC_VER_MAJOR" -lt "2" ]; then
        echo "Autoconf 2.13 or greater needed to build configure."
        exit 1
    fi

    if [ "$AC_VER_MINOR" -lt "13" ]; then
        echo "Autoconf 2.13 or greater needed to build configure."
        exit 1
    fi

    if [ "$AC_VER_MINOR" -lt "50" ]; then
        if [ ! -e configure.in ]; then
            ln -s configure.ac configure.in
        fi
        echo "If you see some warnings about cross-compiling, don't worry; this is normal."
    else
        rm -f configure.in
    fi
else
    echo autoconf not found. renderBitch SVN requires autoconf to bootstrap itself.
    exit 1
fi


run_cmd()
{
    echo "Running $* ..."
    if ! $*; then
        echo "$* failed!"
        exit 1
    fi
}


# Check if /usr/local/share/aclocal exists
if [ -d /usr/local/share/aclocal ]; then
    ACLOCAL_INCLUDE="$ACLOCAL_INCLUDE -I config/m4 -I /usr/local/share/aclocal"
else
    ACLOCAL_INCLUDE="$ACLOCAL_INCLUDE -I config/m4"
fi	


run_cmd aclocal $ACLOCAL_INCLUDE
run_cmd autoheader
run_cmd $LIBTOOLIZE --automake
run_cmd automake --add-missing --copy
run_cmd autoconf

if [ ! -e configure ]; then
    echo "ERROR: configure was not created!"
    exit 1
fi

echo ""
echo "======================================"

if [ -f config.cache ]; then
    echo "config.cache exists.  Removing the config.cache file will force"
    echo "the ./configure script to rerun all it's tests rather than using"
    echo "the previously cached values."
    echo ""
fi

echo "Now you are ready to run './configure'"
echo "======================================"
