/*! \file WIS2D.h
    \author Wojciech Jarosz
*/
/*
    Copyright (C) 2004-2006 by Wojciech Jarosz, University of California, San Diego.
    wjarosz@ucsd.edu

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the
    Free Software Foundation, Inc.,
    59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*/
#ifndef HAAR_WIS_H
#define HAAR_WIS_H

#include <haar/Haar.h>

namespace haar
{

class Wavelet2DBase;
class Square2D;

class WIS2D
{
public:
    typedef std::vector<math::Vec2f*> Points;
    typedef std::vector<math::Vec2f*>::iterator PointIterator;
    typedef std::vector<math::Vec2f*>::const_iterator ConstPointIterator;

    WIS2D (const Wavelet2DBase* wavelet = 0) : m_wavelet (wavelet) {}

    void setPoints (std::vector<math::Vec2f>& p);
    void warpPoints () const;
    void warpPoint (math::Vec2f* p, float* pdf) const;
    
protected:

    void warp (const Square2D& s, float scale,
               Points& p, const math::Box2f& pBox) const;

    const Wavelet2DBase* m_wavelet;
    mutable Points m_points;
    mutable Points m_pointCache[12][4];        // temp storage
};
                      
} // namespace haar
                      
#endif // WAVELET2D_H
