/*! \file SequenceJittered.cpp
    \author Wojciech Jarosz
*/
/*
    Copyright (C) 2004-2006 by Wojciech Jarosz, University of California, San Diego.
    wjarosz@ucsd.edu

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the
    Free Software Foundation, Inc.,
    59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*/
#if HAVE_CONFIG_H
#  include <config.h>
#endif // HAVE_CONFIG_H

#include <rnd/SequenceJittered.h>
#include <rnd/Rand.h>

namespace rnd
{

Jittered::Jittered (unsigned x, unsigned y, float jitter) :
    m_resX (x), m_resY (y), m_jitter (0.5f*jitter), m_indexX (-1),
    m_indexY (0), m_rand (new RandKnuth ())
{
    reset ();
}


Jittered::~Jittered ()
{
    delete m_rand;
}


void
Jittered::reset ()
{
    if (m_resX == 0) m_resX = 1;
    if (m_resY == 0) m_resY = 1;
    m_indexX = -1;
    m_indexY = 0;
    m_indexXScale = 1.0f/m_resX;
    m_indexYScale = 1.0f/m_resY;
    m_rand->init (1);
}


void
Jittered::setIndex (unsigned i)
{
    m_rand->init (53);
    m_indexY = i/m_resY;
    m_indexX = i%m_resX;
}


void
Jittered::next (float r[])
{
    if (++m_indexX == (int)m_resX)
    {
        m_indexX = 0;
        if (++m_indexY == (int)m_resY)
            m_indexY = 0;
    }
    
    float r0 = m_rand->nextf (-m_jitter, m_jitter);
    float r1 = m_rand->nextf (-m_jitter, m_jitter);
    r[0] = (m_indexX + 0.5f + r0)*m_indexXScale;
    r[1] = (m_indexY + 0.5f + r1)*m_indexYScale;
    
}

} // namespace rnd
