/*! \file SequenceJittered.h
    \author Wojciech Jarosz
*/
/*
    Copyright (C) 2004-2006 by Wojciech Jarosz, University of California, San Diego.
    wjarosz@ucsd.edu

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the
    Free Software Foundation, Inc.,
    59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*/
#ifndef RND_SEQUENCE_JITTERED_H
#define RND_SEQUENCE_JITTERED_H

#include <rnd/Sequence.h>

namespace rnd
{
class Rand;

//! Encapsulate a stratified, jittered point set.
class Jittered : public Sequence
{
public:
    Jittered (unsigned resX, unsigned resY, float jitter = 1.0f);
    virtual ~Jittered ();

    virtual void reset ();
    virtual void next (float[]);

    virtual unsigned numSamples () const    {return m_resX*m_resY;}
    virtual void setNumSamples (unsigned n) {m_resX = m_resY = n; reset ();}
    
    virtual unsigned currentIndex () const  {return m_indexY*m_resX + m_indexX;}
    virtual void setIndex (unsigned i);

private:
    unsigned m_resX, m_resY;
    float m_jitter;
    
    int m_indexX, m_indexY;
    float m_indexXScale, m_indexYScale;
    Rand* m_rand;
};

} // namespace rnd

#endif // RND_SEQUENCE_JITTERED_H
