/*! \file SequenceLP.h
    \author Wojciech Jarosz
*/
/*
    Copyright (C) 2004-2006 by Wojciech Jarosz, University of California, San Diego.
    wjarosz@ucsd.edu

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the
    Free Software Foundation, Inc.,
    59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*/
#ifndef RND_SEQUENCE_LP_H
#define RND_SEQUENCE_LP_H

#include <rnd/Sequence.h>
#include <rnd/Misc.h>

namespace rnd
{

//! Encapsulate a efficient Hammersley sequence in base 2.
class LarcherPillichshammerBase2 : public Sequence
{
public:
    LarcherPillichshammerBase2 (unsigned numSamples = 64,
                                unsigned index = 0) :
        m_index (index), m_N (numSamples), m_inv (1.0f/m_N) {}
    virtual ~LarcherPillichshammerBase2 () {}

    virtual void reset ()                   {m_index = 0;}
    virtual void next (float r[])
    {
        r[0] = (m_index % m_N) * m_inv;
        r[1] = LarcherPillichshammerRI (m_index, m_scramble2);
        m_index++;
    }

    virtual unsigned currentIndex () const  {return m_index;}
    virtual void setIndex (unsigned i)      {m_index = i;}

    unsigned numSamples () const            {return m_N;}
    void setNumSamples (unsigned n)
    {
        m_N = (n == 0) ? 1 : n;
        m_inv = 1.0/m_N;
        reset ();
    }

private:
    unsigned m_index;
    unsigned m_N;
    float m_inv;
    unsigned m_scramble1, m_scramble2, m_scramble3;
};

} // namespace rnd

#endif // RND_SEQUENCE_LP_H
