/*!\file EXRIO.cpp
   \author Wojciech Jarosz
*/
/*
    Copyright (C) 2004-2006 by Wojciech Jarosz, University of California, San Diego.
    wjarosz@ucsd.edu

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the
    Free Software Foundation, Inc.,
    59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*/
#if HAVE_CONFIG_H
#  include <config.h>
#endif // HAVE_CONFIG_H

#include <EXRIO.h>
#include <vector>

#include <ImfArray.h>
#include <ImfRgbaFile.h>
#include <ImfInputFile.h>
#include <ImfOutputFile.h>
#include <ImfChannelList.h>
#include <ImfFrameBuffer.h>
#include <half.h>


using namespace Imf;
using namespace Imath;
using std::string;

Color3 * 
readEXRImage (const string &name, int * width, int * height)
{
    Color3* img = 0;
    try
    {
        Imf::RgbaInputFile file (name.c_str ());
        Imath::Box2i dw = file.dataWindow();

        *width  = dw.max.x - dw.min.x + 1;
        *height = dw.max.y - dw.min.y + 1;
        Imf::Array2D<Imf::Rgba> pixels (1, *width);

        int y = dw.min.y;
        int row = 0;
        img = new Color3 [*width * *height];

        while (y <= dw.max.y)
        {
            file.setFrameBuffer (&pixels[0][0] - dw.min.x - dw.min.y * *width,
                                  1, 0);

            file.readPixels (y, y);

            // copy pixels over to the Image
            for (int i = 0; i < *width; ++i)
            {
                const Imf::Rgba &p = pixels[0][i];
                img[*width * row + i] = Color3 (p.r, p.g, p.b);
            }

            y++;
            row++;
        }
    }
    catch (const std::exception &e)
    {
        std::cerr << "Unable to read image file \"" << name
                  << "\": " << e.what () << std::endl;
        delete [] img;
        return 0;
    }
    catch (...)
    {
        std::cerr << "Unable to read image file \"" << name
                  << "\"" << std::endl;
        delete [] img;
        return 0;
    }
    return img;
}

